@@ -1,4 +1,4 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*
  * Copyright (c) 2017, Intel Corporation
  * All rights reserved.
@@ -28,7 +28,7 @@ command_attrs_finalize (GObject *obj)
 {
     CommandAttrs *attrs = COMMAND_ATTRS (obj);
 
-    g_debug ("command_attrs_finalize: %p", objid (attrs));
+    g_debug (__func__);
     g_clear_pointer (&attrs->command_attrs, g_free);
     G_OBJECT_CLASS (command_attrs_parent_class)->finalize (obj);
 }
