@@ -1,4 +1,4 @@
-/* SPDX-License-Identifier: BSD-2 */
+/* SPDX-License-Identifier: BSD-2-Clause */
 /*
  * Copyright (c) 2017, Intel Corporation
  * All rights reserved.
@@ -20,7 +20,7 @@
 
 #include "connection.h"
 #include "connection-manager.h"
-#include "tabrmd.h"
+#include "tabrmd-defaults.h"
 #include "util.h"
 
 static void
@@ -138,7 +138,6 @@ connection_manager_remove_test (void **state)
 int
 main(void)
 {
-    util_init ();
     const struct CMUnitTest tests[] = {
         cmocka_unit_test (connection_manager_allocate_test),
         cmocka_unit_test_setup_teardown (connection_manager_insert_test,
